% System parameters
m = 10;
b = 15;
g = 9.81;
L = 1;

% Equilibria 
xbar = [pi/4 0];
ubar = m*g;

% Output at the equilibria
ybar = xbar(1);

% Variation of the initial conditions
dx0 = [0.3 3];

% Input variation: Am*sin(t)
Am = 10;

% Simulation time interval
tfin = 15;

% Linearized model matrices
A = [ 0 1 ; -sqrt(2)*g/L -b/(m*L^2) ];
B = [ 0 ; 1/(sqrt(2)*m*L) ];
C = [ 1 0 ];
D = 0;

% Linearized model
sys_l = ss(A,B,C,D);
% Time vector
tlin = 0:.001:tfin;
% Linear simulation
du = Am*sin(tlin);
ylin= lsim(sys_l,du,tlin,dx0);
% Nonlinear simulation
[t,x_nl]=ode45('p_nl',[0 tfin],xbar+dx0,[],m,b,g,L,ubar,Am);
y_nl = x_nl(:,1);
% Plots
figure(1)
plot(t,y_nl*180/pi,'-',tlin,(ylin+ybar)*180/pi,'--')
grid on
ylabel('[deg]')
xlabel('Time [s]')
title('\theta')
legend('NL','L')